@@ -26,15 +26,14 @@
 #define BABL_HARD_MAX_PATH_LENGTH  8
 #define BABL_MAX_NAME_LEN          1024
 
-#define BABL_TEST_ITER             4
+#define BABL_TEST_ITER             16
 
 #ifndef MIN
 #define MIN(a, b) (((a) > (b)) ? (b) : (a))
 #endif
 
-#define NUM_TEST_PIXELS            (babl_get_num_path_test_pixels ())
 #define MAX_BUFFER_SIZE            512
-
+#define ITERATIONS                 4
 
 int   babl_in_fish_path = 0;
 
@@ -103,7 +102,7 @@ static int max_path_length (void);
 static int debug_conversions = 0;
 int _babl_instrument = 0;
 
-double 
+double
 _babl_legal_error (void)
 {
   static double error = 0.0;
@@ -133,7 +132,7 @@ _babl_legal_error (void)
   return error;
 }
 
-static int 
+static int
 max_path_length (void)
 {
   static int  max_length = 0;
@@ -146,9 +145,11 @@ max_path_length (void)
   if (env)
     max_length = atoi (env);
   else
-    max_length = 4; /* reducing this number makes finding short fishes much
+    max_length = 3; /* reducing this number makes finding short fishes much
                        faster - even if we lose out on some of the fast
-                       bigger fish
+                       bigger fish, the fishes we can get with a max_length of 3
+                       is actually 5, since we deepen the search twice if no
+                       sufficient results are found.
                      */
   if (max_length > BABL_HARD_MAX_PATH_LENGTH)
     max_length = BABL_HARD_MAX_PATH_LENGTH;
@@ -157,7 +158,7 @@ max_path_length (void)
   return max_length;
 }
 
-int 
+int
 _babl_max_path_len (void)
 {
   return max_path_length ();
@@ -600,6 +601,7 @@ babl_fish_path2 (const Babl *source,
 
     get_conversion_path (&pc, (Babl *) source, 0, max_path_length (), tolerance);
 
+#if 0
     /* second attempt,. at path length + 1*/
     if (babl->fish_path.conversion_list->count == 0 &&
         max_path_length () + 1 <= BABL_HARD_MAX_PATH_LENGTH)
@@ -614,17 +616,33 @@ babl_fish_path2 (const Babl *source,
       }
 #endif
     }
+#endif
 
     /* third attempt,. at path length + 2 */
     if (babl->fish_path.conversion_list->count == 0 &&
         max_path_length () + 2 <= BABL_HARD_MAX_PATH_LENGTH)
     {
       get_conversion_path (&pc, (Babl *) source, 0, max_path_length () + 2, tolerance);
-#if 0
+#if 1
       if (babl->fish_path.conversion_list->count)
       {
-        fprintf (stderr, "babl is using very long chain, should be optimized\n");
-        babl_list_each (babl->fish_path.conversion_list, show_item, NULL);
+        //fprintf (stderr, "babl is a long chain, should be optimized\n");
+        //babl_list_each (babl->fish_path.conversion_list, show_item, NULL);
+      }
+      else
+      {
+         static int show_missing = -1;
+         if (show_missing < 0)
+         {
+            const char *val = getenv ("BABL_DEBUG_MISSING");
+            if (val && strcmp (val, "0"))
+              show_missing = 1;
+            else
+              show_missing = 0;
+         }
+         if (show_missing)
+           fprintf (stderr, "babl is lacking conversion for %s to %s\n",
+               babl_get_name (source), babl_get_name (destination));
       }
 #endif
     }
